pub struct ShuffledRng {
entries: Vec<bool>,
position: usize,
}Expand description
A shuffled finite deck containing a fixed number of successful entries.
Fields
entries: Vec<bool>position: usizeImplementations
Sourceimpl ShuffledRng
impl ShuffledRng
pub fn new(success_entries: u32, total_entries: u32) -> Option<Self>
Sourcepub fn from_valid_counts(success_entries: u32, total_entries: u32) -> Self
pub fn from_valid_counts(success_entries: u32, total_entries: u32) -> Self
Constructs a deck whose counts were validated by the authoring boundary.
Panics
Panics when the deck is empty or contains more successes than entries.
pub fn reset(&mut self)